@@ -11,10 +11,13 @@ A python-logging interface compatible wrapper for logging with :py:mod:`univenti
 >>> logger.info('test')
 """
 
+import contextlib
 import copy
 import datetime
 import logging
+import time
 import traceback
+from typing import Any
 
 from logfmter import Logfmter
 
@@ -64,7 +67,7 @@ _UD_CATEGORIES = {
 }
 
 
-def _map_level_to_ud(level):  # type: (int) -> int
+def _map_level_to_ud(level: int) -> int:
     """
     Map logging level to univention-debug loglevel
 
@@ -107,7 +110,7 @@ def _map_level_to_ud(level):  # type: (int) -> int
     return _LEVEL_MAPPING.get(level, level)
 
 
-def _map_ud_to_level(level):  # type: (int) -> int
+def _map_ud_to_level(level: int) -> int:
     """
     Map univention-debug level to logging loglevel
 
@@ -139,7 +142,7 @@ def _map_ud_to_level(level):  # type: (int) -> int
     return _UD_LEVEL_MAPPING.get(level)
 
 
-def _map_category_name(category):  # type: (int) -> str
+def _map_category_name(category: int) -> str:
     """
     >>> _map_category_name(10)
     'ADMIN'
@@ -147,25 +150,23 @@ def _map_category_name(category):  # type: (int) -> str
     return _UD_CATEGORIES.get(category, '<unknown>')
 
 
-def getLogger(name, **kwargs):  # type: (str) -> Logger
+def getLogger(name: str, **kwargs: Any) -> 'Logger':
     """
     Return a logger with the specified name, creating it if necessary.
 
-    .. param name:
+    :param name:
         The name of a :py:mod:`univention.debug` category
         (if not existant `ud.MAIN` will be used)
+    :param extend:
+        Whether a non univention-debug logger should be extended to be one.
+    :param univention_debug_category:
+        If the logger name should differ from the univention-debug category this param can be used
+        as initialization call to create the logger once.
 
     .. warning::
         If a logger with that name already exists and is not a :py:class:`univention.logging.Logger`
         no univention-debug logger is initialized and returned.
 
-    .. param extend:
-        Whether a non univention-debug logger should be extended to be one.
-
-    .. param univention_debug_category:
-        If the logger name should differ from the univention-debug category this param can be used
-        as initialization call to create the logger once.
-
     >>> logger = getLogger('ADMIN')  # .getChild(__name__)
     >>> logger.init('stdout', ud.FLUSH, ud.NO_FUNCTION)
     >>> logger.setLevel(logging.WARNING)
@@ -184,15 +185,13 @@ def getLogger(name, **kwargs):  # type: (str) -> Logger
     return logger
 
 
-def extendLogger(name, **kwargs):  # type: (str) -> None
+def extendLogger(name: str, **kwargs: Any) -> None:
     """
     Ensure that the logger with the specified name is a univention-debug logger otherwise transform it.
 
-    .. param name:
-        The name of the logger.
-
-    .. param univention_debug_category:
-        A :py:mod:`univention.debug` category (if not given :param:`name` will be used).
+    :param name: The name of the logger.
+    :param univention_debug_category:
+        A :py:mod:`univention.debug` category (if not given `name` will be used).
         If the logger name should differ from the univention-debug category this param can be used
         as initialization call to create the logger once.
 
@@ -303,11 +302,12 @@ class SyslogPrefix(logging.Filter):
 
 
 class StructuredFormatter(logging.Formatter):
-    """
+    r"""
     A formatter combining prefixed content and structured data from logfmt.
 
     Producing log lines like:
-    2025-01-01T00:00:00.000000+00:00 INFO    [         -] module.function:1 the message\t| pid=12345 logname=ADMIN
+
+       2025-01-01T00:00:00.000000+00:00 INFO    [         -] module.function:1 the message\t| pid=12345 logname=ADMIN
     """
 
     def __init__(
@@ -357,7 +357,7 @@ class StructuredFormatter(logging.Formatter):
                     setattr(record, key, val)
         try:
             record.message = record.getMessage().replace('\t|', '\t\\|')
-            if '\n' in record.message:
+            if record.message.strip('\t !"#$%&\'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~'):
                 record.message = self.logfmter.format_string(record.message)
             if self.usesTime():
                 record.asctime = self.formatTime(record, self.datefmt)
@@ -385,7 +385,7 @@ class Logger(logging.Logger):
     """
     A logger which automatically adds :py:mod:`univention.debug` as logging handler.
 
-    Can be set as global default logger via `logging.setLoggerClass(univention.logging.Logger)`.
+    Can be set as global default logger via ``logging.setLoggerClass(univention.logging.Logger)``.
     """
 
     def __init__(self, name, level=logging.NOTSET, log_pid=False, **kwargs):
@@ -491,6 +491,15 @@ class Structured:
         _kwargs.setdefault('exc_info', True)
         _self._log(_self.__log.exception, _message, *_args, **_kwargs)
 
+    @contextlib.contextmanager
+    def timing(_self, _message, *_args, level=logging.TRACE, stacklevel=1, **_kwargs):
+        start = time.perf_counter()
+        try:
+            yield
+        finally:
+            end = time.perf_counter()
+            _self.log(level, _message, *_args, stacklevel=stacklevel + 2, duration=f"{end - start:.6f}", **_kwargs)
+
     def _log(_self, _func, _msg, *args, exc_info=None, stack_info=False, stacklevel=1, **extra):
         return _func(
             _msg,
@@ -542,6 +551,7 @@ class LevelDependentFormatter(logging.Formatter):
     A formatter which logs different formats depending on the log level.
 
     .. deprecated:: 5.2-3
+
        unstructured logging with different formats will be removed in UCS 5.2-5.
     """
 
