@@ -29,6 +29,7 @@ def normalize_logformat(log):
         re.compile(r'Traceback \(most recent call last\):(.|\n)*?NameError: name .+ is not defined'): '<TRACEBACK>',
         re.compile(r'Stack \(most recent call last\):(.|\n)*?, i, stack_info=True\)'): '<STACK>',
         re.compile(r'test_logging\.[a-z_]+:\d+'): 'test_module.test_function:1',
+        re.compile(r'duration=\d.\d{6}'): 'duration=0.000111',
         # legacy
         re.compile(r'^\d{2}.\d{2}.\d{2} \d{2}:\d{2}:\d{2}\.\d{3}', re.M): '01.01.25 00:00:00.000',
         re.compile(f': {os.getpid()}:'): ': 12345:',
@@ -80,8 +81,11 @@ def test_log_structured_with_time(tmp_path):
     logger.trace('message')
     logger.log(6, 'message')
     logger.getChild('blah').error('message')
+    with logger.timing('message'):
+        pass
     try:
-        foobar()
+        with logger.timing('message'):
+            foobar()
     except NameError:
         logger.exception('message')
     assert logger.root
@@ -98,6 +102,8 @@ NoneType: None
 <7>2025-01-01T00:00:00.000000+00:00    TRACE [         -] message\t| pid=12345 logname=bar func=test_module.test_function:1 foo=bar
 <7>2025-01-01T00:00:00.000000+00:00  Level 6 [         -] message\t| pid=12345 logname=bar func=test_module.test_function:1 foo=bar
 <3>2025-01-01T00:00:00.000000+00:00    ERROR [         -] message\t| pid=12345 logname=bar.blah func=test_module.test_function:1 foo=bar
+<7>2025-01-01T00:00:00.000000+00:00    TRACE [         -] message\t| pid=12345 logname=bar func=test_module.test_function:1 foo=bar duration=0.000111
+<7>2025-01-01T00:00:00.000000+00:00    TRACE [         -] message\t| pid=12345 logname=bar func=test_module.test_function:1 foo=bar duration=0.000111
 <3>2025-01-01T00:00:00.000000+00:00    ERROR [         -] message\t| pid=12345 logname=bar func=test_module.test_function:1 foo=bar exc_info="<TRACEBACK>"
 <TRACEBACK>
 """.strip()
@@ -178,14 +184,6 @@ def test_logging(tmp_path, debug_backend, strucutured):
     logger.info({'msg': 'logger.info({"msg": "msg"}, "foo": "bar")', 'foo': 'bar'})
     logger.info('logger.info("msg", extra={"foo": "bar"})', extra={'foo': 'bar'})
     logger.info('logger.info("msg %s", "addition", extra={"foo": "bar"})', '%s', extra={'foo': 'bar'})
-    logger.info('contains null (\x00) byte')
-    logger.info('contains', extra={'null': '(\x00) byte'})
-    logger.info('contains new (\n) line')  # FIXME: new line allowed
-    logger.info('contains', extra={'new': '(\n) line'})
-    logger.info('contains', extra={'new(\n) ': 'line'})
-    logger.info('muha\t| foo=bar')  # FIXME: no escaping
-    logger.info('muha', extra={'param': 'ha\t| foo=bar'})  # FIXME: no escaping
-    logger.info('muha\t| foo=bar', extra={'param': 'ha\t| foo=bar'})  # FIXME: no escaping
     for i in [False, True]:
         logger.univention_debug_handler.formatter.add_full_tracebacks = i
         try:
@@ -195,6 +193,23 @@ def test_logging(tmp_path, debug_backend, strucutured):
             child.exception('child.exception("full_tb=%s")', i)
         logger.info('logger.info("full_tb=%s", stack_info=True)', i, stack_info=True)
     logger.error('logger.error("msg", extra={"traceback": "<TRACEBACK>"})', extra={'traceback': '<TRACEBACK>'})
+    # security
+    logger.info('contains null (\x00) byte')
+    logger.info('contains', extra={'null': '(\x00) byte'})
+    logger.info('contains new (\n) line')  # FIXME: new line allowed
+    logger.info('contains', extra={'new': '(\n) line'})
+    logger.info('contains', extra={'new(\n) ': 'line'})
+    logger.info('muha\t| foo=bar')  # FIXME: no escaping
+    logger.info('muha', extra={'param': 'ha\t| foo=bar'})  # FIXME: no escaping
+    logger.info('muha\t| foo=bar', extra={'param': 'ha\t| foo=bar'})  # FIXME: no escaping
+    logger.info('')
+    logger.info(' ')
+    logger.info('\n')
+    logger.info('\r')
+    logger.info('\t')
+    logger.info(''.join(map(chr, range(0x80))))
+    logger.info('x', extra={'userinput': ''.join(map(chr, range(0x80)))})
+    logger.info('x', extra={''.join(map(chr, range(0x80))): 'x'})
 
     logger.univention_debug_handler.close()
 
